@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.122 2005/01/24 20:21:33 vnoel Exp $ */
+/* $Id: gdict-app.c,v 1.123 2005/02/01 21:54:42 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -217,8 +217,9 @@ gdict_lookup_web (GDictWindow *gdict, gchar *text)
 }
 
 static void
-gdict_lookup_entry (GDictWindow *gdict) 
+gdict_lookup_cb (GtkAction *action, GtkWidget *widget)
 {
+  GDictWindow *gdict = GDICT_WINDOW (widget);
   gchar *text = NULL;
 
   text = gtk_editable_get_chars (GTK_EDITABLE (gdict->word_entry), 0, -1);
@@ -230,20 +231,6 @@ gdict_lookup_entry (GDictWindow *gdict)
   g_free (text);
 }
 
-static void
-gdict_lookup_cb (GtkAction *action, GtkWidget *widget)
-{
-  GDictWindow *gdict = GDICT_WINDOW (widget);
-  gdict_lookup_entry(gdict);
-}
-
-static void
-gdict_lookup_button_cb (GtkButton *button, gpointer data)
-{
-  GDictWindow *gdict = data;
-  gdict_lookup_entry(gdict);
-}
-
 static void
 gdict_menu_item_set_sensitive (GDictWindow *gdict, char *path, gboolean sensitive)
 {
@@ -783,7 +770,7 @@ gdict_window_init (GDictWindow *gdict)
          G_N_ELEMENTS (drop_targets), GDK_ACTION_COPY | GDK_ACTION_MOVE);
   gtk_tool_item_set_is_important (GTK_TOOL_ITEM (menu_button), TRUE);
   g_signal_connect (G_OBJECT (menu_button), "clicked",
-        G_CALLBACK (gdict_lookup_button_cb), gdict);
+        G_CALLBACK (gdict_lookup_cb), gdict);
   g_signal_connect (G_OBJECT (button), "drag_data_received",
         G_CALLBACK (gdict_lookup_button_drag_cb), gdict);
 
