@@ -1,7 +1,7 @@
 #ifndef __GDICT_PREF_H_
 #define __GDICT_PREF_H_
 
-/* $Id: gdict-pref.h,v 1.10 2004/12/14 18:56:47 vnoel Exp $ */
+/* $Id: gdict-pref.h,v 1.11 2004/12/21 20:13:33 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -62,6 +62,7 @@ gchar* gdict_get_gconf_string (GDictWindow *gdict, gchar *key);
 void gdict_set_gconf_int (GDictWindow *gdict, gchar *key, int value);
 void gdict_set_gconf_bool (GDictWindow *gdict, gchar *key, gboolean bool);
 void gdict_set_gconf_string (GDictWindow *gdict, gchar *key, gchar *string);
-void gdict_window_store_geometry (GDictWindow *gdict);
+void gdict_window_store_position (GDictWindow *gdict);
+void gdict_window_restore_position (GDictWindow *gdict);
 
 #endif /* __GDICT_PREF_H_ */
