@@ -22,6 +22,12 @@
 #ifdef __CYGWIN__
 #define timezonevar
 #endif
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <string.h>
